NewWindowResponse

Enum NewWindowResponse 

pub enum NewWindowResponse {
    Allow,
    Create {
        webview: WebView,
    },
    Deny,
}
Response for the new window request handler.

See WebViewBuilder::with_new_window_req_handler.

Variants



Allow

Allow the window to be opened with the default implementation.



Create

Available on neither Android nor iOS.

Allow the window to be opened, with the given platform webview instance.

Platform-specific:

Linux: The webview must be related to the caller webview. See WebViewBuilderExtUnix::with_related_view. Windows: The webview must use the same environment as the caller webview. See [WebViewBuilderExtWindows::with_environment]. macOS: The webview must use the same configuration as the caller webview. See [WebViewBuilderExtMacos::with_webview_configuration].

Fields

webview: WebView
Available on Linux or DragonFly BSD or FreeBSD or NetBSD or OpenBSD only.


Deny

Deny the window from being opened.