WebViewBuilderExtUnix

Trait WebViewBuilderExtUnix 

pub trait WebViewBuilderExtUnix<'a> {
    // Required methods
    fn build_gtk<W>(self, widget: &'a W) -> Result<WebView>
       where W: IsA<Container>;
    fn with_extensions_path(self, path: impl Into<PathBuf>) -> Self;
    fn with_related_view(self, webview: WebView) -> Self;
}
Available on Linux or DragonFly BSD or FreeBSD or NetBSD or OpenBSD only.

Required Methods

fn build_gtk<W>(self, widget: &'a W) -> Result<WebView>
where W: IsA<Container>,

Consume the builder and create the webview inside a GTK container widget, such as GTK window.

Panics:
  • Panics if gtk::init was not called in this thread.
fn with_extensions_path(self, path: impl Into<PathBuf>) -> Self

Set the path from which to load extensions from.

Creates a new webview sharing the same web process with the provided webview. Useful if you need to link a webview to another, for instance when using the WebViewBuilder::with_new_window_req_handler.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors